@@ -38,8 +38,9 @@ HTTP_RESPONSE_CODES = ["100", "101", "200", "201", "202", "203", "204", "205", "
 
 root = os.path.dirname(os.path.abspath(__file__))
 templates_dir = os.path.join(root, 'templates')
-fuzz_words_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'fuzzdb/attack')
-fuzz_types = ["fuzzdb/attack"]#os.listdir(os.path.join(root, "fuzzdb/attack"))#["general", "injections", "vulns", "webservices", "stress", "others"]
+fuzz_words_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), os.path.join('fuzzdb','attack'))
+fuzz_types = [os.path.join("fuzzdb","attack")]#os.listdir(os.path.join(root, "fuzzdb/attack"))#["general", "injections", "vulns", "webservices", "stress", "others"]
+supoorted_fuzz_types = [_ for _ in os.listdir(fuzz_words_dir) if "README" not in _]
 ANOMOLY_THRESHOLD = 1.07142
 RESERVED_PARAMETERS = ["$RESPONSE_ERROR", "$CV_EVENT_ID"]
 
@@ -614,7 +615,7 @@ class CloudvectorDAST(object):
                 with open("tests/test_" + str(filename) + ".py", 'w+') as fh:
                     fh.write(template.render(apis_metadata=apis_to_be_tested[k], api_name=k, host_url=host_url,
                                              fuzzing_details=fuzzing_details, fuzz_type=str(type),
-                                             stateful_fuzz=statefull))
+                                             stateful_fuzz=statefull, fuzz_supported=supoorted_fuzz_types))
                 files_created.add("test_" + str(filename))
 
         print("\n\t\t......done creating pytest methods for fuzzing: " + str(files_created))
@@ -753,7 +754,7 @@ class CloudvectorDAST(object):
         return spaarc_findings
 
     @staticmethod
-    def generate_fuzz_report():
+    def generate_fuzz_report(output_report):
         if not os.path.exists(os.path.join(os.getcwd(), 'tests/data/attack_info.json')):
             print("\n\n\tThe flag '--generate-report' is a beta version only applicable for FUZZ tests at the moment!\n")
             return
@@ -771,7 +772,7 @@ class CloudvectorDAST(object):
             for type, subtype in attack_info.items():
                 for name, info in subtype.items():
                     #print(name, info.get("file_set"), in_file, "\n\n\n")
-                    if str(in_file).lower() in [str(_).split("/")[-1].lower() for _ in info.get("file_set",[])]:
+                    if str(in_file).lower() in [str(_).replace("\\","/").split("/")[-1].lower() for _ in info.get("file_set",[])]:
                         return info
             return None
 
@@ -795,11 +796,11 @@ class CloudvectorDAST(object):
             except:
                 response_code = 0
             try:
-                fuzz_sub_type = metadata.split("::")[3].split("/")[-1]
+                fuzz_sub_type = metadata.split("::")[3].replace("\\","/").split("/")[-1]
             except:
                 fuzz_sub_type = "na"
             try:
-                fuzz_type = metadata.split("::")[3].replace(fuzz_sub_type,"").replace("attack","").replace("//","/").split("/")[1]
+                fuzz_type = metadata.split("::")[3].replace(fuzz_sub_type,"").replace("\\","/").replace("attack","").replace("//","/").split("/")[1]
             except:
                 fuzz_type = "na"
             try:
@@ -810,6 +811,7 @@ class CloudvectorDAST(object):
                 curl_command_to_try = stdout.split("CURL command to retry:")[-1].split("---------------------------------")[0].replace("\n","")
             except:
                 curl_command_to_try = ""
+
             if api_name not in consolidated_report:
                 consolidated_report[api_name] = {}
             if api_method not in consolidated_report[api_name]:
@@ -995,13 +997,14 @@ class CloudvectorDAST(object):
         for severity, types in fuzz_types.items():
             for k, v in types.items():
                 vulns_stats[severity] = len(v.get("executions",[]))
-        with open("cviast_report.html", "w+") as file_:
+        with open(output_report, "w+") as file_:
             file_.write(template.render(api_data=api_data, fuzz_data=fuzz_data_processed, total_api_calls=total_api_calls,
                                         total_vulnerabilities=vulnerabilities_found, spaarc_findings=spaarc_findings,
                                         test_time=datetime.datetime.fromtimestamp(time.time()).isoformat(), total_apis_scanned=total_apis,
                                         fuzz_types=fuzz_types, vulns_stats=vulns_stats, fuzz_metadata=fuzz_metainfo,
+                                        detailed_report=os.path.join(os.getcwd(),"CVIAST-detailed_report.html"),
                                         test_lapse_time=str(round(int(report["report"]["summary"]["duration"])/60))+" min(s)"))
-        print("CVIAST report saved in " + str(os.getcwd()) + "/cviast_report.html")
+        print("CVIAST report saved in " + os.path.join(os.getcwd(),output_report))
 
 def printProgressBar (iteration, total, prefix = '', suffix = '', decimals = 1, length = 100, fill = '█', printEnd = "\r"):
     """
@@ -1037,20 +1040,29 @@ def main():
     # parser.add_argument('vars', nargs='*')
     #
     # args = parser.parse_args()
-
+    html_report_name = "CVIAST-report.html"
     if sys.argv[1:]:
+        for _ in sys.argv[1:]:
+            if "report-out" in _:
+                html_report_name = _.split("=")[-1]
+                sys.argv.remove(_)
+        if sys.argv[1:][0] == "--list-supported-fuzz-types":
+            print("\n\t\t\t\t\t\t".join(supoorted_fuzz_types))
+            return
         if sys.argv[1:][0] == "--generate-report":
-            CloudvectorDAST.generate_fuzz_report()
+            CloudvectorDAST.generate_fuzz_report(html_report_name)
             return
         if sys.argv[1:][0] == "--execute":
             arguments = sys.argv[2:]
             arguments += ["--json=report.json", "--html=CVIAST-detailed_report.html", "--self-contained-html", "-vv"]
             try:
                 pytest.main(arguments)
-                CloudvectorDAST.generate_fuzz_report()
+                CloudvectorDAST.generate_fuzz_report(html_report_name)
             except:
                 pass
             return
+
+    print(sys.argv)
     if os.path.exists(os.path.join(os.getcwd(), "my_cesetup.yaml")):
         with open(os.path.join(os.getcwd(), "my_cesetup.yaml")) as fobj:
             ce_details = yaml.load(fobj, Loader=yaml.FullLoader)
